#include <stdio.h>
#include <stdlib.h>
#include <errno.h>

#include "s3vn.h"

int main(int argc, char **argv)
{

  int rc;
  char *repo_name;

  // Get the local repository path from the command line arguments
  if (argc != 2)
  {
    printf("Usage: fetchrepo <local repository path>\n");
    return 1;
  }
  repo_name = argv[1];

  printf("Repository name is %s\n", repo_name);

  // Initialize s3vn configuration
  init_s3vn( repo_name,
             get_env_or_die("SVNZOO_BUCKET"),
             get_env_or_die("SVNZOO_PREFIX"),
             get_env_or_die("SVNZOO_ZKADDR"),
             get_env_or_die("SVNZOO_ZKPREFIX")
           );

  // Connect to ZooKeeper
  rc = create_session();
  if (rc == -1)
  {
    fprintf(stderr, "Could not connect to ZooKeeper\n");
    exit(1);
  }

  // Create a repository locally
  rc = create_local_repo();
  if (rc == -1)
  {
    fprintf(stderr, "Could not create local repository\n");
    exit(1);
  }

  // Fetch the repository from S3/ZooKeeper
  fetch_repo();

  // Disconnect from ZooKeeper
  end_session();

  return 0;
}
