#ifndef _S3VN_H
#define _S3VN_H

struct s3vn_config
{
  char *local_repo;
  char *s3_bucket;
  char *s3_prefix;
  char *zk_addr;
  char *zk_prefix;
};

// Initialize the s3vn module
void init_s3vn(char* local_repo, char* s3_bucket, char* s3_prefix, char* zk_addr, char* zk_prefix);

// Set program name (for preventing temporary file conflicts)
void set_progname(char *pn);

// Create an empty repository on the local disk
int create_local_repo(void);

// Fetch a repository from S3/ZooKeeper
int fetch_repo(void);

// Store a local repository info S3/ZooKeeper
int store_repo(void);

// Fetch the specified revision from S3 to the local repository
int fetch_rev(int revnum);

// Push the specified revision from the local repository into S3
int store_rev(int revnum);

// Set the current revision number in the local repository
int set_current(int revnum);

// Get the current revision number from the local repository
int get_current(void);

// Set the transaction number in the local repository
int set_txn(int txnnum);

// Get the transaction number from the local repository
int get_txn(void);

// Push the current revision number into ZooKeeper
int store_current(int revnum);

// Get the number of the latest revision that ZooKeeper knows about
int fetch_current(void);

// Wait until a revision greater than current_rev is available, then return
int watch_current(int current_rev);

// Push the current transaction number into ZooKeeper
int store_txn(int txnnum);

// Get the latest transaction number that ZooKeeper knows about
int fetch_txn(void);

// Acquire a lock for modifying the repository
int acquire_lock(void);

// Release the lock for modifying the repository
int release_lock(void);

// Check if the lock is held (returns 1 if held, 0 if not held, -1 on error)
int check_lock(void);

// Create a new ZooKeeper session
int create_session(void);

// End the ZooKeeper session
int end_session(void);

// Save the ZooKeeper client_id to the local repository
int save_session(void);

// Delete the ZooKeeper client_id from the local repository
int delete_session(void);

// Load an existing ZooKeeper client_id from the repository and connect the ZooKeeper session
int restore_session(void);

// Get an environment variable, printing a mesage and exiting if it is missing
char* get_env_or_die(char* env_name);

#endif
