#include <stdio.h>
#include <stdlib.h>
#include <errno.h>

#include "s3vn.h"

int main(int argc, char **argv)
{

  int rc;
  char *repo_name;
  //int current_local, current_zoo, txn_local, txn_zoo;
  int current_local, current_zoo;

  // Get the local repository path from the command line arguments
  if (argc < 4)
  {
    printf("Usage: start-commit-hook <repos_path> <user> <capabilities>\n");
    return 1;
  }
  repo_name = argv[1];

  printf("Repository name is %s\n", repo_name);

  // Initialize s3vn configuration
  init_s3vn( repo_name,
             get_env_or_die("SVNZOO_BUCKET"),
             get_env_or_die("SVNZOO_PREFIX"),
             get_env_or_die("SVNZOO_ZKADDR"),
             get_env_or_die("SVNZOO_ZKPREFIX")
           );

  // Avoid temporary file naming conflicts
  set_progname("start");

  // Connect to ZooKeeper
  rc = create_session();
  if (rc == -1)
  {
    fprintf(stderr, "Could not connect to ZooKeeper\n");
    exit(1);
  }

  // Grab a repository write lock
  rc = acquire_lock();
  if (rc == -1)
  {
    fprintf(stderr, "Could not get repository write lock from ZooKeeper\n");
    end_session();
    exit(1);
  }

  // Get local and authoritative version info
  current_local = get_current();
  //txn_local = get_txn();
  current_zoo = fetch_current();
  //txn_zoo = fetch_txn();
  //if (current_local == -1 || txn_local == -1 || current_zoo == -1 || txn_zoo == -1)
  if (current_local == -1 || current_zoo == -1)
  {
    //fprintf(stderr, "Error in (current_local, txn_local, current_zoo, txn_zoo): (%d, %d, %d, %d)\n",
    //        current_local, txn_local, current_zoo, txn_zoo);
    fprintf(stderr, "Error in (current_local, current_zoo): (%d, %d)\n", current_local, current_zoo);
    release_lock(); // ignore any errors (actually may not be necessary at all, if lock is ephemeral)
    end_session();
    exit(1);
  }

  // Some sanity checks, for good measure...
  if (current_local > current_zoo)
  {
    fprintf(stderr, "ZooKeeper is out of data. How can this happen??\n");
    fprintf(stderr, "ZooKeeper version: %d\nLocal version: %d\n", current_zoo, current_local);
    release_lock(); // ignore any errors (actually may not be necessary at all, if lock is ephemeral)
    end_session();
    exit(1);
  }

  // Make sure the local repository is fully up to date
  for (int revnum=current_local+1; revnum<=current_zoo; revnum++)
  {
    rc = fetch_rev(revnum);
    if (rc == -1)
    {
      fprintf(stderr, "Could not fetch revision %d\n", revnum);
      release_lock(); // ignore any errors (actually may not be necessary at all, if lock is ephemeral)
      end_session();
      exit(1);
    }
  }
  rc = set_current(current_zoo);
  if (rc == -1)
  {
    fprintf(stderr, "Cannot set current revision to %d\n", current_zoo);
    exit(1);
  }
  //if (txn_zoo > txn_local)
  //{
  //  rc = set_txn(txn_zoo);
  //  if (rc == -1)
  //  {
  //    fprintf(stderr, "Could not set local transaction number to %d\n", txn_zoo);
  //    release_lock(); // ignore any errors (actually may not be necessary at all, if lock is ephemeral)
  //    end_session();
  //    exit(1);
  //  }
  //}

  // Save the ZooKeeper session, to be reconnected in the post-commit-hook
  rc = save_session();
  if (rc == -1)
  {
    fprintf(stderr, "Could not save ZooKeeper session\n");
    release_lock(); // ignore any errors (actually may not be necessary at all, if lock is ephemeral)
    end_session();
    exit(1);
  }

  return 0;
}
