#include <stdio.h>
#include <stdlib.h>
#include <errno.h>

#include "s3vn.h"

int main(int argc, char **argv)
{

  int rc;
  char *repo_name;
  int current_rev, latest_rev;

  // Get the local repository path from the command line arguments
  if (argc != 2)
  {
    printf("Usage: updaterepo <local repository path>\n");
    return 1;
  }
  repo_name = argv[1];

  printf("Repository name is %s\n", repo_name);

  // Initialize s3vn configuration
  init_s3vn( repo_name,
             get_env_or_die("SVNZOO_BUCKET"),
             get_env_or_die("SVNZOO_PREFIX"),
             get_env_or_die("SVNZOO_ZKADDR"),
             get_env_or_die("SVNZOO_ZKPREFIX")
           );

  // Avoid temporary file naming conflicts
  set_progname("update");

  // Determine the local version
  current_rev = get_current();
  if (current_rev == -1)
  {
    fprintf(stderr, "Cannot read current version from local repository\n");
    exit(1);
  }

  // Connect to ZooKeeper
  rc = create_session();
  if (rc == -1)
  {
    fprintf(stderr, "Could not connect to ZooKeeper\n");
    exit(1);
  }

  while (1)
  {

    // Wait for a newer version to become available
    latest_rev = watch_current(current_rev);
    if (latest_rev == -1)
    {
      fprintf(stderr, "Failed while waiting for a notification from ZooKeeper\n");
      end_session();
      exit(1);
    }

    printf("Got notified that the latest rev is %d\n", latest_rev);

    // Download the newer version(s)
    for (int i=current_rev+1; i<=latest_rev; i++)
    {
      rc = fetch_rev(i);
      if (rc == -1)
      {
        fprintf(stderr, "Could not update local repository to rev %d\n", i);
        end_session();
        exit(1);
      }
      rc = set_current(i);
      if (rc == -1)
      {
        fprintf(stderr, "Could not update current file in local repository to rev %d\n", i);
        end_session();
        exit(1);
      }
      printf("Fetched rev %d from S3\n", i);
    }
    current_rev = latest_rev;

  }

  // Disconnect from ZooKeeper
  end_session();

  return 0;
}
